GridConfigurationPatterns extension

Adds pattern-matching-related methods to GridConfiguration.

on

Methods

map<TResult extends Object?>(TResult $default(_GridConfiguration value)) → TResult

Available on GridConfiguration, provided by the GridConfigurationPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_GridConfiguration value)?) → TResult?

Available on GridConfiguration, provided by the GridConfigurationPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_GridConfiguration value)?, {required TResult orElse()}) → TResult

Available on GridConfiguration, provided by the GridConfigurationPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(Map<String, Object?> settings)?, {required TResult orElse()}) → TResult

Available on GridConfiguration, provided by the GridConfigurationPatterns extension

A variant of when that fallback to an orElse callback.
when<TResult extends Object?>(TResult $default(Map<String, Object?> settings)) → TResult

Available on GridConfiguration, provided by the GridConfigurationPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(Map<String, Object?> settings)?) → TResult?

Available on GridConfiguration, provided by the GridConfigurationPatterns extension

A variant of when that fallback to returning null