Key constructor

const Key(
  1. String value
)

Constructs a ValueKey that matches on the equality of the given string.

This is the ergonomic default for the overwhelmingly common string-keyed case (key: const Key('counter') is ValueKey<String>('counter')).

Implementation

const factory Key(String value) = ValueKey<String>;