ReferenceKind enum
Link target classifier for a DiagnosticsProperty.reference.
Values
- bead → const ReferenceKind
- session → const ReferenceKind
- substation → const ReferenceKind
- pid → const ReferenceKind
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
ReferenceKind> - A constant List of the values in this enum, in order of their declaration.