ReloadRequest class

Re-run the master build on the SAME delegate.

Inheritance

Constructors

ReloadRequest(int generation)
Creates the reload request at generation.
const

Properties

generation int
The monotonic re-composition counter; 0 is the launch baseline (never a request).
finalinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited