buildWithChild abstract method
Describes the subtree for the current configuration and state, embedding
child (the downstream link or leaf).
Implementation
@protected
Seed buildWithChild(TreeContext context, Seed child);
Describes the subtree for the current configuration and state, embedding
child (the downstream link or leaf).
@protected
Seed buildWithChild(TreeContext context, Seed child);