Owns the off-tree half of a live substation attachment.
- Implementers
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
ownedIdentityTokens
→ Set<
String> -
Every identity token the station currently owns.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
decommission(
String name) → Future< int> -
Tears down
name's resources and returns the reaped worktree count. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
provision(
SubstationWorkSpec spec) → Future< void> -
Starts
spec's controller, membership, writer, root, and ownership. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited