TreeSnapshot class final
A complete versioned projection of the live diagnostics tree.
Constructors
- TreeSnapshot({required int contractVersion, required DateTime projectedAt, required TreeNode root})
-
Creates a full snapshot stamped at
projectedAt.const -
TreeSnapshot.fromJson(Map<
String, Object?> json) -
Decodes a complete snapshot from its wire representation.
factory
Properties
- contractVersion → int
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- projectedAt → DateTime
-
final
- root → TreeNode
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{int? contractVersion, DateTime? projectedAt, TreeNode? root}) → TreeSnapshot -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override